# Unischeduler
* This program is intended for students in universities where Oracle Peoplesoft Campus Solutions is used (if your student self service is absolutely horrible, your university probably uses PCS)
* Unischeduler converts your schedule from text to an icalendar format to export into any known calendar service (google calendar, apple calendar, outlook calendar, etc)
* There is a [separate graphical interface](https://github.com/Ovsyanka83/unischeduler_gui) available
